@@ -1,8 +1,8 @@
 use strict;
 use warnings;
 
-package URI::cpan::author;
-$URI::cpan::author::VERSION = '1.006';
+package URI::cpan::author 1.008;
+
 use parent qw(URI::cpan);
 
 sub validate {
@@ -36,11 +36,21 @@ URI::cpan::author
 
 =head1 VERSION
 
-version 1.006
+version 1.008
+
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
