@@ -1,9 +1,9 @@
 use strict;
 use warnings;
 
-package URI::cpan::distfile;
+package URI::cpan::distfile 1.008;
 # ABSTRACT: cpan:///distfile/AUTHOR/Dist-1.234.tar.gz
-$URI::cpan::distfile::VERSION = '1.006';
+
 use parent qw(URI::cpan);
 
 use Carp ();
@@ -93,13 +93,23 @@ URI::cpan::distfile - cpan:///distfile/AUTHOR/Dist-1.234.tar.gz
 
 =head1 VERSION
 
-version 1.006
+version 1.008
 
 =head1 SYNOPSIS
 
 This URL refers to a file in an author directory on the CPAN, and expects the
 format AUTHOR/DISTFILE
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 =head1 dist_name
@@ -122,7 +132,7 @@ This returns the name of the author whose file is referred to.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
